Приветствую всёх наших любителей Python, думаю многим из вас надоедало то что когда вы получаете время используя Datetime мы получаем не особо красивые текста, что-же я решыл исправить это
термины:
[] - что-то из этого
{не обязательно}
<> - сложить вместе
int - число
str - строка
list - листинг
dict - словарь
tuple - кортеж

функции:
get([int, <int, str>], {str}) - функция сложения, имеет два аргумента и оба не обязательны: 
time = укажите время
lounge = укажите язык перевода (умолчание Англ.)